# eloy

Image Processing for Astronomy

---

A simple Python package containing functions to process astronomical images. This package aims at being simple and relies on a minimal number of dependencies. The development philosophy of this package is to stick as much as possible to the functional programming paradigm by avoiding the definition of object classes.

In this documentation we provide tutorials applied to different [example datasets](datasets) that you may want to download beforehand. Some of these tutorials teach you how to do certain useful things in Astronomy, rather than being solely focused on *eloy*.

## Table of contents

```{toctree}
:caption: Getting Started
:maxdepth: 1

install
```

```{toctree}
:caption: Tutorials
:maxdepth: 1

datasets
calibration
stacking
video
plate-solving
target
photometry
```

```{toctree}
:caption: Developer Documentation
:maxdepth: 1

ballet
contributing
glossary

```